@@ -19,20 +19,14 @@ class RenderNode(template.Node):
         self.block = block
 
     def render(self, context):
-        for d in context:
-            for k in d.keys():
-                if k == 'user':
-                    context.user = d[k]
-
         b = context[self.block]
         context_dict = {}
         for d in context.dicts:
             context_dict.update(d)
         # can only take string keys
         for k in context_dict.keys():
-            if isinstance(k, str):
+            if not isinstance(k, str):
                 del context_dict[k]
-        context_dict['request'] = context
         return b.render(**context_dict)
 
 
@@ -47,20 +41,14 @@ class RenderJSNode(template.Node):
         self.block = block
 
     def render(self, context):
-        for d in context:
-            for k in d.keys():
-                if k == 'user':
-                    context.user = d[k]
-
         b = context[self.block]
         context_dict = {}
         for d in context.dicts:
             context_dict.update(d)
         # can only take string keys
         for k in context_dict.keys():
-            if isinstance(k, str):
+            if not isinstance(k, str):
                 del context_dict[k]
-        context_dict['request'] = context
         return b.render_js(**context_dict)
 
 
@@ -75,20 +63,14 @@ class RenderCSSNode(template.Node):
         self.block = block
 
     def render(self, context):
-        for d in context:
-            for k in d.keys():
-                if k == 'user':
-                    context.user = d[k]
-
         b = context[self.block]
         context_dict = {}
         for d in context.dicts:
             context_dict.update(d)
         # can only take string keys
         for k in context_dict.keys():
-            if isinstance(k, str):
+            if not isinstance(k, str):
                 del context_dict[k]
-        context_dict['request'] = context
         return b.render_css(**context_dict)
 
 
@@ -103,20 +85,14 @@ class RenderSummaryNode(template.Node):
         self.block = block
 
     def render(self, context):
-        for d in context:
-            for k in d.keys():
-                if k == 'user':
-                    context.user = d[k]
-
         b = context[self.block]
         context_dict = {}
         for d in context.dicts:
             context_dict.update(d)
         # can only take string keys
         for k in context_dict.keys():
-            if isinstance(k, str):
+            if not isinstance(k, str):
                 del context_dict[k]
-        context_dict['request'] = context
         return b.render_summary(**context_dict)
 
 
